@@ -1,3 +1,4 @@
+# vim: set fileencoding=utf-8 :
 # GNU Solfege - free ear training software
 # Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008  Tom Cato Amundsen
 #
@@ -538,6 +539,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         but lets see if that can improve.
         """
         self.handle_config_box_visibility()
+        self.handle_statistics_page_sensibility()
     def on_end_practise(self):
         pass
     def handle_config_box_visibility(self):
@@ -550,6 +552,16 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
             self.config_box.show()
         else:
             self.config_box.hide()
+    def handle_statistics_page_sensibility(self):
+        try:
+            if self.m_t.m_custom_mode:
+                self.g_statview.set_sensitive(False)
+                self.g_statview.set_tooltip_text(_("Statistics is disabled. Either because you selected a “Configure yourself” exercise, or because “Expert mode” is selected in the preferences window."))
+            else:
+                self.g_statview.set_sensitive(True)
+                self.g_statview.set_tooltip_text(None)
+        except AttributeError: # not all exercises has g_statview
+            pass
     def on_key_press_event(self, widget, event):
         if (self.g_notebook is None or self.g_notebook.get_current_page() == 0) \
            and event.type == gtk.gdk.KEY_PRESS:
@@ -567,13 +579,10 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         self.g_notebook.connect('switch_page', self.on_switch_page)
     def on_switch_page(self, notebook, obj, pagenum):
         if pagenum == 2:
-            if isinstance(self.m_t, Teacher):
-                if self.m_t.m_P:
-                    self.g_statview.update()
-                else:
-                    self.g_statview.clear()
-            else:
+            if self.m_t.m_P and not self.m_t.m_custom_mode:
                 self.g_statview.update()
+            else:
+                self.g_statview.clear()
     def _add_auto_new_question_gui(self, box):
         hbox = gu.bHBox(box, False)
         hbox.set_spacing(gu.PAD_SMALL)
@@ -595,10 +604,7 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         hbox.pack_start(spin, False)
     def _lessonfile_exception(self, exception, sourcefile, lineno):
         m = ExceptionDialog(exception)
-        try:
-            idx = exception.m_question_idx
-        except AttributeError:
-            idx = self.m_t.m_P._idx
+        idx = self.m_t.m_P._idx
         if idx is not None:
             m.add_text(_('Please check question number %(idx)i in the lesson file "%(lf)s".') % {'idx': self.m_t.m_P._idx+1, 'lf': self.m_t.m_P.m_filename})
         if 'm_nonwrapped_text' in dir(exception):
@@ -611,18 +617,14 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         m.run()
         m.destroy()
     def _mpd_exception(self, exception, sourcefile, lineno):
-        try:
-            idx = exception.m_question_idx + 1
-        except AttributeError:
-            idx = self.m_t.m_P._idx + 1
         m = ExceptionDialog(exception)
         if 'm_mpd_varname' in dir(exception):
             m.add_text(_('Failed to parse the music in the variable "%(varname)s" in question number %(idx)i in the lesson file "%(lf)s".') % {
-                'idx': idx,
+                'idx': self.m_t.m_P._idx + 1,
                 'lf': lessonfile.uri_expand(self.m_t.m_P.m_filename),
                 'varname': exception.m_mpd_varname})
         else:
-            m.add_text(_('Failed to parse the music for question number %(idx)i in the lesson file "%(lf)s".') % {'idx': idx, 'lf': lessonfile.uri_expand(self.m_t.m_P.m_filename)})
+            m.add_text(_('Failed to parse the music for question number %(idx)i in the lesson file "%(lf)s".') % {'idx': self.m_t.m_P._idx + 1, 'lf': lessonfile.uri_expand(self.m_t.m_P.m_filename)})
         if 'm_mpd_badcode' in dir(exception):
             m.add_nonwrapped_text(exception.m_mpd_badcode)
         m.add_text(_('The exception was caught in\n"%(filename)s", line %(lineno)i.') % {'filename': sourcefile, 'lineno': lineno})
@@ -867,9 +869,9 @@ class LessonbasedGui(Gui):
         response = dlg.run()
         if response == gtk.RESPONSE_OK:
             self.m_t.m_P.header.random_transpose = dlg.get_value()
-            if self.m_t.m_P.header.random_transpose:
+            if self.m_t.m_P.header.random_transpose[0] == True:
                 self.g_random_transpose.set_text(_("Yes"))
-            elif not self.m_t.m_P.header.random_transpose:
+            elif self.m_t.m_P.header.random_transpose[0] == False:
                 self.g_random_transpose.set_text(_("No"))
             else:
                 self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
@@ -899,6 +901,7 @@ class LessonbasedGui(Gui):
             else:
                 solfege.win.display_in_musicviewer(self.m_t.m_P.get_music(varname))
         except mpd.MpdException, e:
+            self.m_t.m_P.get_question()[varname].complete_to_musicdata_coords(self.m_t.m_P, e)
             e.m_mpd_varname = varname
             e.m_mpd_badcode = self.m_t.m_P.get_question()[varname].get_err_context(e, self.m_t.m_P)
             if not self.standard_exception_handler(e):
