@@ -152,7 +152,7 @@ else:
     splash_win = None
 
 if splash_win:
-    splash_win.show_progress("importing application modules")
+    splash_win.show_progress(_("Importing application modules"))
 
 from solfege import tracebackwindow
 # redirect error messages to a window that will popup if
@@ -297,7 +297,7 @@ class ExerciseView(SelectWinBase):
         gu.bButton(self.g_searchbox, _("Search"), callback=self.on_search, expand=False)
         self.show_all()
     def _display_data(self, page, display_only_tests=False,
-            is_search_result=False):
+            is_search_result=False, show_topics=False):
         """
         display_only_tests should be True when we are browsing available tests.
         This will validate statistics for each lesson and display the test result.
@@ -348,6 +348,10 @@ class ExerciseView(SelectWinBase):
                         try:
                             labeltxt = lessonfile.infocache.get(link, 'title')
                             label = gu.ClickableLabel(_no_xgettext(labeltxt))
+                            if show_topics:
+                                topic = solfege.app.m_frontpage_data.get_topic_of_lesson_file(link)
+                                if topic and topic not in labeltxt:
+                                    label.add_heading(topic)
                             label.connect('clicked', self.on_link_clicked, link)
                         except lessonfile.InfoCache.FileNotFound:
                             label = gu.ClickableLabel(_(u"«%s» was not found") % link)
@@ -361,9 +365,12 @@ class ExerciseView(SelectWinBase):
                     w = label.size_request()[0]
                     if w > self.max_exercise_label_width:
                         w = self.max_exercise_label_width
-                        txt = _(lessonfile.infocache.get(link, "title"))
+                        if isinstance(link, unicode):
+                            txt = _(lessonfile.infocache.get(link, "title"))
+                        else:
+                            txt = link.m_name
                         label.set_tooltip_text(txt)
-                        label.set_size_request(w, -1)
+                        label.set_size_request(w / len(page), -1)
                     self.m_linkbuttons.append(label)
                     label.connect('focus-in-event', self.on_focus_in)
                     if display_only_tests:
@@ -443,8 +450,9 @@ class ExerciseView(SelectWinBase):
 
 class FrontPage(ExerciseView):
     def display_data(self, data, display_only_tests=False,
-            is_search_result=False):
-        self._display_data(data, display_only_tests, is_search_result)
+            is_search_result=False, show_topics=False):
+        self._display_data(data, display_only_tests, is_search_result,
+                           show_topics)
         self.g_searchentry.grab_focus()
     def on_search(self, *button):
         search_for = self.g_searchentry.get_text().lower()
@@ -461,8 +469,8 @@ class FrontPage(ExerciseView):
 class TestsView(ExerciseView):
     def on_link_clicked(self, w, filename):
         solfege.app.test_lessonfile(filename)
-    def display_data(self, data=None, is_search_result=False):
-        self._display_data(data, True, is_search_result)
+    def display_data(self, data=None, is_search_result=False, show_topics=False):
+        self._display_data(data, True, is_search_result, show_topics)
         self.g_searchentry.grab_focus()
     def on_search(self, *button):
         search_for = self.g_searchentry.get_text().lower()
@@ -611,9 +619,9 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             lambda o: solfege.app.handle_href('theory-intervals.html')),
           ('TreeEditor', None, _('_Edit Front Page'), None, None,
             self.do_tree_editor),
-          ('ExportTrainingSet', None, _('E_xport Exercises to Audio Files'), None, None,
+          ('ExportTrainingSet', None, _(u'E_xport Exercises to Audio Files…'), None, None,
             self.new_training_set_editor),
-          ('EditPractiseSheet', None, _('Ear Training Test Pri_ntout'), None, None,
+          ('EditPractiseSheet', None, _(u'Ear Training Test Pri_ntout…'), None, None,
             self.new_practisesheet_editor),
           ('OpenPreferencesWindow', 'gtk-preferences', None, '<ctrl>F12', None,
             self.open_preferences_window),
@@ -623,10 +631,12 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
           ('FrontPage', None, _('_Front Page'), 'F5', None,
               lambda w: self.display_frontpage()),
           ('TestsPage', None, _('_Tests Page'), 'F6', None,
-              self.display_testpage),
+              lambda w: self.display_testpage()),
           ('RecentExercises', None, _('_Recent Exercises'), 'F7', None,
               self.display_recent_exercises),
-          ('UserExercises', None, _('_User Exercises'), 'F8', None,
+          ('RecentTests', None, _('_Recent Tests'), 'F8', None,
+              self.display_recent_tests),
+          ('UserExercises', None, _('_User Exercises'), 'F9', None,
               self.display_user_exercises),
           ('HelpHelp', 'gtk-help', _('_Help on the current exercise'), 'F1', None,
             lambda o: solfege.app.please_help_me()),
@@ -635,8 +645,10 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             lambda o: solfege.app.handle_href('index.html')),
           ('HelpShowPathInfo', None, _('_File locations'), None,
             None, self.show_path_info),
-          ('HelpOnline', None, _('_Mailinglists, web page etc.'), None, None,
+          ('HelpOnline', None, _('_Mailing lists, web page etc.'), None, None,
             lambda o: solfege.app.handle_href('online-resources.html')),
+          ('HelpDonate', None, _('_Donate'), None, None,
+            lambda o: solfege.app.handle_href('http://www.solfege.org/Main/Donate')),
           ('HelpReportingBugs', None, _('Reporting _bugs'), None, None,
             lambda o: solfege.app.handle_href('bug-reporting.html')),
           ('HelpAbout', 'gtk-about', None, None, None, self.show_about_window),
@@ -807,6 +819,8 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             box2.pack_start(gu.hig_label_widget(_("Solfege config file:"), gtk.Label(filesystem.rcfile()), sizegroup))
             box2.pack_start(gu.hig_label_widget(_("Solfege installation directory:"), gtk.Label(os.getcwdu()), sizegroup))
             box2.pack_start(gu.hig_label_widget(_("User manual in HTML format:"), gtk.Label(os.path.join(os.getcwdu(), "help")), sizegroup))
+            box2.pack_start(gu.hig_label_widget("gtk:", gtk.Label(str(gtk)), sizegroup))
+            box2.pack_start(gu.hig_label_widget("PYTHONHOME", gtk.Label(os.environ.get('PYTHONHOME', 'Not defined')), sizegroup))
             self.g_path_info_dlg.show_all()
             def f(*w):
                 self.g_path_info_dlg.hide()
@@ -910,55 +924,6 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             print >> sys.stderr, "\n".join(textwrap.wrap("Translations are disabled because your locale settings are broken. This is not a bug in GNU Solfege, so don't report it. The README file distributed with the program has some more details."))
         except AttributeError:
             pass
-    def display_discarded_lessonfiles_info(self):
-        assert solfege.app.lessonfile_manager.m_discards
-        dlg = gtk.Dialog(_("Discarded lesson files"), buttons=(gtk.STOCK_OK, gtk.RESPONSE_ACCEPT))
-        dlg.set_default_response(gtk.RESPONSE_ACCEPT)
-        cbox = gtk.VBox()
-        dlg.vbox.pack_start(cbox)
-        cbox.set_border_width(12)
-        dlg.set_default_size(400, 300)
-        l = gtk.Label(_("The lesson files listed below was discarded by the program, and will not be available in the program until the errors are corrected."))
-        l.set_line_wrap(True)
-        cbox.pack_start(l, False)
-        sc = gtk.ScrolledWindow()
-        sc.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-        vbox = gtk.VBox()
-        sc.add_with_viewport(vbox)
-        cbox.pack_start(sc)
-        for idx, info in enumerate(solfege.app.lessonfile_manager.m_discards):
-            sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-            ibox = gtk.VBox()
-            row1 = gtk.HBox()
-            row1.set_spacing(8)
-            ibox.pack_start(row1, False)
-            l = gtk.Label(_("Filename:"))
-            l.set_alignment(1.0, 0.5)
-            sizegroup.add_widget(l)
-            row1.pack_start(gtk.Label(_("Filename:")), False)
-            row1.pack_start(gtk.Label(info['filename']), False)
-            row2 = gtk.HBox()
-            row2.set_spacing(8)
-            ibox.pack_start(row2, False)
-            l = gtk.Label(_("Reason:"))
-            l.set_alignment(1.0, 0.5)
-            sizegroup.add_widget(l)
-            row2.pack_start(l, False)
-            if 'exception' in info:
-                estr = str(info['exception']).decode(sys.getfilesystemencoding(), 'replace')
-                row2.pack_start(gtk.Label(estr), False)
-            elif 'reason' in info:
-                if info['reason'] == 'no module':
-                    msg = _("Missing module declaration")
-                else:
-                    msg = _("Unknown")
-                row2.pack_start(gtk.Label(msg), False)
-            vbox.pack_start(ibox, False)
-            if idx < len(solfege.app.lessonfile_manager.m_discards) - 1:
-                vbox.pack_start(gtk.HSeparator(), False)
-        dlg.show_all()
-        dlg.run()
-        dlg.destroy()
     def activate_exercise(self, module, urlobj=None):
         self.show_view(module)
         # We need this test because not all exercises use a notebook.
@@ -992,6 +957,17 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
                 linklist = frontpage.LinkList(dir)
                 col.append(linklist)
             linklist.append(filename)
+        # Move ~/.solfege/exercises/user/lesson-files first in the list
+        # since we refer to this directory in the user manual
+        for idx, c in enumerate(col):
+            if c[0].startswith(os.path.join(filesystem.user_data(), u"exercises", u"user", u"lesson-files")):
+                col.insert(0, c)
+                del col[idx+1]
+                break
+        else:
+            linklist = frontpage.LinkList(os.path.join(filesystem.user_data(), u"exercises", u"user", u"lesson-files"))
+            col.insert(0, linklist)
+            
         if os.path.isdir(filesystem.user_lessonfiles()):
             linklist = None
             # Added just to be nice with people not moving their files from
@@ -1009,9 +985,16 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
             [frontpage.Column(
                 [frontpage.LinkList(_('Recent exercises'),
                    solfege.db.recent(8))])])
-        self.display_frontpage(data)
+        self.display_frontpage(data, show_topics=True)
         self.get_view().g_searchbox.hide()
-    def display_testpage(self, widget=None):
+    def display_recent_tests(self, w):
+        data = frontpage.Page(_('Recent tests'),
+            [frontpage.Column(
+                [frontpage.LinkList(_('Recent tests'),
+                   solfege.db.recent_tests(8))])])
+        self.display_testpage(data, show_topics=True)
+        self.get_view().g_searchbox.hide()
+    def display_testpage(self, data=None, show_topics=False):
         """
         Display the front page of the data  in solfege.app.m_frontpage_data
         """
@@ -1019,12 +1002,14 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         if not self.show_view('testspage'):
             self.add_view(TestsView(), 'testspage')
         self.get_view().g_searchbox.show()
-        self.get_view().display_data(solfege.app.m_frontpage_data)
+        if not data:
+            data = solfege.app.m_frontpage_data
+        self.get_view().display_data(data, show_topics=show_topics)
     def on_search_all_exercises(self, widget=None):
         self.set_title("GNU Solfege")
         if not self.show_view('searchview'):
             self.add_view(SearchView(), 'searchview')
-    def display_frontpage(self, data=None):
+    def display_frontpage(self, data=None, show_topics=False):
         """
         Display the front page of the data  in solfege.app.m_frontpage_data
         """
@@ -1034,7 +1019,7 @@ class MainWin(gtk.Window, cfg.ConfigUtils):
         self.get_view().g_searchbox.show()
         if not data:
             data = solfege.app.m_frontpage_data
-        self.get_view().display_data(data)
+        self.get_view().display_data(data, show_topics=show_topics)
     def initialise_exercise(self, teacher):
         """
         Create a Gui object for the exercise and add it to
@@ -1108,20 +1093,18 @@ application.check_rcfile()
 
 cfg.set_bool('config/no_random', bool(options.no_random))
 
-if splash_win:
-    splash_win.show_progress("creating LessonfileManager")
 lessonfile.infocache = lessonfile.InfoCache()
 
 if splash_win:
     if not os.path.exists(statistics.DB.get_statistics_filename()):
-        splash_win.show_progress("Importing old statistics:")
+        splash_win.show_progress(_("Importing old statistics"))
 def f(s):
     if splash_win:
         splash_win.show_progress(s)
 solfege.db = statistics.DB(f)
 
 if splash_win:
-    splash_win.show_progress("creating MainWin")
+    splash_win.show_progress(_("Creating application window"))
 
 def start_app(datadir):
     global splash_win
